Sphinx .Net Domain
==================

.. image:: https://readthedocs.org/projects/sphinxcontrib-dotnetdomain/badge/?version=latest
   :target: https://sphinxcontrib-dotnetdomain.readthedocs.org
   :alt: Documentation Status

.. image:: https://travis-ci.org/rtfd/sphinxcontrib-dotnetdomain.svg?branch=master
   :target: https://travis-ci.org/rtfd/sphinxcontrib-dotnetdomain

This package provides a .NET domain for Sphinx documentation.

The best place to look for functionality currently is the `tests <https://github.com/rtfd/sphinxcontrib-dotnetdomain/tree/master/tests>`_.

Contents
--------

.. toctree::
   :caption: Main
   :glob:
   :maxdepth: 2

   design

.. toctree::
   :caption: API
   :glob:
   :maxdepth: 2

   autoapi/index

